@@ -180,15 +180,15 @@ typedef size_t os_bufsize_t;
 #ifndef s6_addr16
 #if defined(s6_words)
 #define s6_addr16 s6_words
-#elif defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
+#elif defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
 #define s6_addr16 __u6_addr.__u6_addr16
 #endif
 #endif
 
 #define set(s, f)   ((s)->flags |= (f))
 #define clear(s, f) ((s)->flags &= ~(f))
-#define true(s, f)  ((s)->flags & (f))
-#define false(s, f) (!true(s, f))
+#define ison(s, f)  ((s)->flags & (f))
+#define isoff(s, f) (!ison(s, f))
 
 #define PLSOCK_MAGIC  0x38da3f2c
 #define PLSOCK_CMAGIC 0x38da3f2d
@@ -440,10 +440,10 @@ without dispatching if no input is available.
 
 static int
 wait_socket(plsocket *s)
-{ if ( true(s, PLSOCK_DISPATCH) )
+{ if ( ison(s, PLSOCK_DISPATCH) )
   { int fd = s->socket;
 
-    if ( true(s, PLSOCK_NONBLOCK) && !PL_dispatch(fd, PL_DISPATCH_INSTALLED) )
+    if ( ison(s, PLSOCK_NONBLOCK) && !PL_dispatch(s->input, PL_DISPATCH_INSTALLED) )
     {
 #ifdef HAVE_POLL
       struct pollfd fds[1];
@@ -470,7 +470,7 @@ wait_socket(plsocket *s)
     } else
     { int rc;
 
-      if ( !(rc = PL_dispatch(fd, PL_DISPATCH_WAIT)) )
+      if ( !(rc = PL_dispatch(s->input, PL_DISPATCH_WAIT)) )
 	errno = EPLEXCEPTION;
       return rc;
     }
@@ -911,7 +911,7 @@ nbio_closesocket(nbio_sock_t socket)
 
   clear(socket, PLSOCK_VIRGIN);
 
-  if ( true(socket, PLSOCK_OUTSTREAM|PLSOCK_INSTREAM) )
+  if ( ison(socket, PLSOCK_OUTSTREAM|PLSOCK_INSTREAM) )
   { int flags = socket->flags;		/* may drop out! */
 
     if ( flags & PLSOCK_INSTREAM )
@@ -968,8 +968,9 @@ nbio_setopt(nbio_sock_t socket, nbio_option opt, ...)
     { const char *dev = va_arg(args, char*);
 
 #ifdef SO_BINDTODEVICE
+      size_t len = strlen(dev); /* check length? */
       if ( setsockopt(socket->socket, SOL_SOCKET, SO_BINDTODEVICE,
-		      dev, strlen(dev)) == 0 )
+		      dev, (socklen_t) len) == 0 ) /* dubious cast */
       { rc = 0;
         break;
       }
@@ -1089,7 +1090,7 @@ nbio_get_flags(nbio_sock_t socket)
 Translate a host + port-number into a sockaddr structure.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-static int
+static bool
 nbio_get_port(term_t Port, int *port)
 { char *name;
 
@@ -1099,13 +1100,13 @@ nbio_get_port(term_t Port, int *port)
     if ( !(service = getservbyname(name, "tcp")) )
       return pl_error(NULL, 0, NULL, ERR_EXISTENCE, "service", Port);
 
-    *port = ntohs(service->s_port);
+    *port = ntohs((uint16_t) service->s_port); /* safe cast */
     DEBUG(1, Sdprintf("Service %s at port %d\n", name, *port));
-    return TRUE;
+    return true;
   }
 
   if ( PL_get_integer(Port, port) )
-    return TRUE;
+    return true;
 
   return pl_error(NULL, 0, NULL, ERR_ARGTYPE, -1, Port, "port");
 }
@@ -1430,7 +1431,7 @@ nbio_accept(nbio_sock_t master, struct sockaddr *addr, socklen_t *addrlen)
   s = allocSocket(slave);
   s->flags |= PLSOCK_ACCEPT;
 #ifndef __WINDOWS__
-  if ( true(s, PLSOCK_NONBLOCK) )
+  if ( ison(s, PLSOCK_NONBLOCK) )
     nbio_setopt(s, TCP_NONBLOCK);
 #endif
 
@@ -1461,7 +1462,7 @@ nbio_listen(nbio_sock_t socket, int backlog)
 
 ssize_t
 nbio_read(nbio_sock_t socket, char *buf, size_t bufSize)
-{ int n;
+{ ssize_t n;
 
   VALID_SOCKET(socket);
 
@@ -1505,7 +1506,7 @@ nbio_write(nbio_sock_t socket, char *buf, size_t bufSize)
   VALID_SOCKET(socket);
 
   while( len > 0 )
-  { int n;
+  { ssize_t n;
 
     n = send(socket->socket, str, (os_bufsize_t)len, 0);
     if ( n < 0 )
@@ -1522,8 +1523,7 @@ nbio_write(nbio_sock_t socket, char *buf, size_t bufSize)
       }
       nbio_error(GET_ERRNO, TCP_ERRNO);
       return -1;
-    }
-    if ( n < len )
+    } else if ( (size_t)n < len )		/* (else) n >= 0 */
     { if ( PL_handle_signals() < 0 )
       { errno = EPLEXCEPTION;
         return -1;
@@ -1570,11 +1570,11 @@ nbio_close_input(nbio_sock_t socket)
 
   DEBUG(2, Sdprintf("[%d]: nbio_close_input(%p, flags=0x%x)\n",
 		    PL_thread_self(), socket, socket->flags));
-  if ( true(socket, PLSOCK_INSTREAM) )
+  if ( ison(socket, PLSOCK_INSTREAM) )
   { clear(socket, PLSOCK_INSTREAM);
 
     socket->input = NULL;
-    if ( false(socket, (PLSOCK_INSTREAM|PLSOCK_OUTSTREAM)) )
+    if ( isoff(socket, (PLSOCK_INSTREAM|PLSOCK_OUTSTREAM)) )
       rc = closeSocket(socket);
 
     if ( socket->symbol )
@@ -1602,7 +1602,7 @@ nbio_close_output(nbio_sock_t socket)
   DEBUG(2, Sdprintf("[%d]: nbio_close_output(%p, flags=0x%x)\n",
 		    PL_thread_self(), socket, socket->flags));
 
-  if ( true(socket, PLSOCK_OUTSTREAM) )
+  if ( ison(socket, PLSOCK_OUTSTREAM) )
   { clear(socket, PLSOCK_OUTSTREAM);
 
     if ( socket->socket != INVALID_SOCKET )
@@ -1612,7 +1612,7 @@ nbio_close_output(nbio_sock_t socket)
     }
 
     socket->output = NULL;
-    if ( false(socket, (PLSOCK_INSTREAM|PLSOCK_OUTSTREAM)) )
+    if ( isoff(socket, (PLSOCK_INSTREAM|PLSOCK_OUTSTREAM)) )
       rc = (rc + closeSocket(socket)) ? -1 : 0;
 
     if ( socket->symbol )
@@ -1630,7 +1630,7 @@ nbio_close_output(nbio_sock_t socket)
 ssize_t
 nbio_recvfrom(nbio_sock_t socket, void *buf, size_t bufSize, int flags,
 	     struct sockaddr *from, socklen_t *fromlen)
-{ int n;
+{ ssize_t n;
 
   VALID_SOCKET(socket);
 
