@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2002-2023, University of Amsterdam
+    Copyright (c)  2002-2025, University of Amsterdam
                               VU University Amsterdam
 			      SWI-Prolog Solutions b.v.
     All rights reserved.
@@ -43,6 +43,7 @@
 #include <SWI-Prolog.h>
 #include "error.h"
 #include <stdlib.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <signal.h>
 #include <math.h>
@@ -136,11 +137,11 @@ generating an exception.
 static void
 print_trace (void)
 { void *array[100];
-  size_t size;
+  int size;
   char **strings;
-  size_t i;
+  int i;
 
-  size = backtrace(array, sizeof(array)/sizeof(void *));
+  size = backtrace(array, (int) (sizeof(array)/sizeof(void *))); /* safe cast */
   strings = backtrace_symbols(array, size);
 
 #ifdef _REENTRANT
@@ -446,12 +447,12 @@ nextEvent(schedule *sched)
 
 
 typedef struct
-{ int		*bits;
+{ unsigned int *bits;
   size_t	size;
   size_t	high;
 } bitvector;
 
-#define BITSPERINT (8*sizeof(int))
+#define BITSPERINT (8*sizeof(unsigned int))
 
 static int
 set_bit(bitvector *v, size_t bit)
@@ -459,8 +460,8 @@ set_bit(bitvector *v, size_t bit)
   int bi = bit%BITSPERINT;
 
   while ( offset >= v->size )
-  { size_t osize = v->size * sizeof(int);
-    int *newbits = realloc(v->bits, osize*2);
+  { size_t osize = v->size * sizeof(*v->bits);
+    unsigned int *newbits = realloc(v->bits, osize*2);
 
     if ( !newbits )
       return FALSE;
@@ -473,11 +474,11 @@ set_bit(bitvector *v, size_t bit)
   { size_t ho = v->high/BITSPERINT;
     int    b  = v->high%BITSPERINT;
 
-    v->bits[ho] &= ~(1<<(b-1));
+    v->bits[ho] &= ~(1<<b);
     v->high++;
   }
 
-  v->bits[offset] |= 1<<(bi-1);
+  v->bits[offset] |= 1<<bi;
   return TRUE;
 }
 
@@ -488,7 +489,7 @@ is_set(bitvector *v, size_t bit)
   { size_t offset = bit/BITSPERINT;
     int bi = bit%BITSPERINT;
 
-    return (v->bits[offset] & (1<<(bi-1))) != 0;
+    return (v->bits[offset] & (1<<bi)) != 0;
   }
 
   return FALSE;
@@ -749,7 +750,7 @@ unify_timer(term_t t, Event ev)
 }
 
 
-static int
+static bool
 get_timer(term_t t, Event *ev)
 { if ( TheSchedule()->stop )
     return FALSE;
@@ -767,13 +768,13 @@ get_timer(term_t t, Event *ev)
         return TRUE;
       } else
       { return pl_error("get_timer", 1, NULL,
-			ERR_DOMAIN, t, "alarm");
+			ERR_DOMAIN, t, "alarm"),false;
       }
     }
   }
 
   return pl_error("get_timer", 1, NULL,
-		  ERR_ARGTYPE, 1, t, "alarm");
+		  ERR_ARGTYPE, 1, t, "alarm"),false;
 }
 
 
