@@ -3,7 +3,8 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2018, VU University Amsterdam
+    Copyright (c)  2018-2023, VU University Amsterdam
+			      SWI-Prolog Solutions b.v.
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -39,6 +40,10 @@
 #include <math.h>
 #include <assert.h>
 
+#ifdef _MSC_VER
+#define strdup(s) _strdup(s)
+#endif
+
 atom_t ATOM_null;
 atom_t ATOM_true;
 atom_t ATOM_false;
@@ -423,7 +428,7 @@ static unsigned int
 MurmurHashAligned2(const void * key, size_t len, unsigned int seed)
 { const unsigned int m = 0x5bd1e995;
   const int r = 24;
-  unsigned int h = seed ^ len;
+  unsigned int h = seed ^ (unsigned int)len;
   const unsigned char * data = (const unsigned char *)key;
 
   while( len >= 4 )
@@ -469,7 +474,7 @@ rehash(htable *t)
       hcell *n;
 
       for(; c; c=n)
-      { int k = MurmurHashAligned2(c->name, strlen(c->name), SEED) % newsize;
+      { size_t k = MurmurHashAligned2(c->name, strlen(c->name), SEED) % newsize;
 
 	n = c->next;
 	c->next = new[k];
@@ -490,7 +495,7 @@ rehash(htable *t)
 static int
 add_anchor(htable *t, const char *name, term_t value)
 { const char *s = name;
-  unsigned int k;
+  size_t k;
   hcell *c;
 
   if ( t->count > t->size )
@@ -514,7 +519,7 @@ add_anchor(htable *t, const char *name, term_t value)
 
 term_t
 find_anchor(htable *t, const char *name)
-{ unsigned int k = MurmurHashAligned2(name, strlen(name), SEED) % t->size;
+{ size_t k = MurmurHashAligned2(name, strlen(name), SEED) % t->size;
   hcell *c;
 
   for(c=t->entries[k]; c; c=c->next)
