@@ -134,7 +134,7 @@ defOperator(Module m, atom_t name, unsigned char type, short priority, int force
 { GET_LD
   operator *op;
   int t = (type & OP_MASK);		/* OP_PREFIX, ... */
-  int must_reg = FALSE;
+  int must_reg = false;
 
   DEBUG(MSG_OPERATOR, Sdprintf(":- op(%d, %s, %s) in module %s\n",
 			       priority,
@@ -167,7 +167,7 @@ defOperator(Module m, atom_t name, unsigned char type, short priority, int force
   { ;
   } else if ( priority < 0 )
   { PL_UNLOCK(L_OP);				/* already inherited: do not change */
-    return TRUE;
+    return true;
   } else
   { op = allocHeapOrHalt(sizeof(*op));
 
@@ -178,7 +178,7 @@ defOperator(Module m, atom_t name, unsigned char type, short priority, int force
     op->type[OP_INFIX]       = OP_INHERIT;
     op->type[OP_POSTFIX]     = OP_INHERIT;
 
-    must_reg = TRUE;
+    must_reg = true;
   }
 
   op->priority[t] = priority;
@@ -189,7 +189,7 @@ defOperator(Module m, atom_t name, unsigned char type, short priority, int force
   }
   PL_UNLOCK(L_OP);
 
-  return TRUE;
+  return true;
 }
 
 
@@ -222,8 +222,9 @@ visibleOperator(Module m, atom_t name, int kind)
 }
 
 
-int
-currentOperator(Module m, atom_t name, int kind, unsigned char *type, short *priority)
+bool
+currentOperator(Module m, atom_t name, int kind,
+		unsigned char *type, short *priority)
 { operator *op;
 
   assert(kind >= OP_PREFIX && kind <= OP_POSTFIX);
@@ -243,11 +244,11 @@ currentOperator(Module m, atom_t name, int kind, unsigned char *type, short *pri
 		     *priority,
 		     PL_atom_chars(m->name)));
 
-      succeed;
+      return true;
     }
   }
 
-  fail;
+  return false;
 }
 
 
@@ -357,7 +358,7 @@ PRED_IMPL("op", 3, op, PL_FA_TRANSPARENT|PL_FA_ISO)
   term_t name = A3;
 
   if ( !PL_strip_module(name, &m, name) )
-    return FALSE;
+    return false;
   if ( m == MODULE_system )
   { term_t t = PL_new_term_ref();
     term_t a = PL_new_term_ref();
@@ -370,16 +371,16 @@ PRED_IMPL("op", 3, op, PL_FA_TRANSPARENT|PL_FA_ISO)
   }
 
   if ( !PL_get_atom_ex(type, &tp) )
-    return FALSE;
+    return false;
   if ( !PL_get_integer_ex(pri, &p) )
-    return FALSE;
+    return false;
   if ( !((p >= 0 && p <= OP_MAXPRIORITY) || (p == -1 && m != MODULE_user)) )
     return PL_error(NULL, 0, NULL, ERR_DOMAIN, ATOM_operator_priority, pri);
   if ( !(t = atomToOperatorType(tp)) )
     return PL_error(NULL, 0, NULL, ERR_DOMAIN, ATOM_operator_specifier, type);
 
   if ( PL_get_atom(name, &nm) )
-  { return defOperator(m, nm, t, (short)p, FALSE);
+  { return defOperator(m, nm, t, (short)p, false);
   } else
   { term_t l = PL_copy_term_ref(name);
     term_t e = PL_new_term_ref();
@@ -387,14 +388,14 @@ PRED_IMPL("op", 3, op, PL_FA_TRANSPARENT|PL_FA_ISO)
     while( PL_get_list_ex(l, e, l) )
     { if ( !PL_get_atom(e, &nm) )
 	return PL_error(NULL, 0, NULL, ERR_TYPE, ATOM_atom, e);
-      if ( !defOperator(m, nm, t, (short)p, FALSE) )
-	return FALSE;
+      if ( !defOperator(m, nm, t, (short)p, false) )
+	return false;
     }
     if ( !PL_get_nil_ex(l) )
-      return FALSE;
+      return false;
   }
 
-  return TRUE;
+  return true;
 }
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -507,7 +508,7 @@ current_op(DECL_LD Module m, int inherit,
       if ( PL_is_variable(name) )
 	nm = NULL_ATOM;
       else if ( !PL_get_atom_ex(name, &nm) )
-	return FALSE;
+	return false;
 
       if ( PL_is_variable(prec) )
       { p = 0;
@@ -515,7 +516,7 @@ current_op(DECL_LD Module m, int inherit,
       { if ( !(p > 0 && p <= 1200) )
 	  return PL_domain_error("operator_priority", prec);
       } else
-      { return FALSE;
+      { return false;
       }
 
       if ( PL_is_variable(type) )
@@ -525,7 +526,7 @@ current_op(DECL_LD Module m, int inherit,
 	  return PL_error(NULL, 0, NULL, ERR_DOMAIN,
 			  ATOM_operator_specifier, type);
       } else
-	return FALSE;
+	return false;
 
       e = allocHeapOrHalt(sizeof(*e));
       b = &e->buffer;
@@ -573,7 +574,7 @@ current_op(DECL_LD Module m, int inherit,
     { if ( e->index == mx )
       { discardBuffer(&e->buffer);
         freeHeap(e, sizeof(*e));
-	return TRUE;
+	return true;
       }
       ForeignRedoPtr(e);
     }
@@ -596,18 +597,18 @@ get_op_module(DECL_LD term_t a3, term_t name, Module *m)
 
   if ( !(p=stripModuleName(valTermRef(a3), &mname)) ||
        !(w=linkValG(p)) )
-    return FALSE;
+    return false;
   *valTermRef(name) = w;
 
   if ( *m && (*m)->name == mname )
-    return TRUE;
+    return true;
   if ( mname && !(*m=acquireModule(mname)) )
   { DEBUG(MSG_OPERATOR, Sdprintf("Could not acquire module %s\n",
 				 PL_atom_chars(mname)));
     *m = MODULE_user;
   }
 
-  return TRUE;
+  return true;
 }
 
 
@@ -623,10 +624,10 @@ PRED_IMPL("current_op", 3, current_op,
   if ( CTX_CNTRL != FRG_CUTTED )
   { if ( !(name = PL_new_term_ref()) ||
 	 !get_op_module(A3, name, &m) )
-      return FALSE;
+      return false;
   }
 
-  rc = current_op(m, TRUE, A1, A2, name, PL__ctx);
+  rc = current_op(m, true, A1, A2, name, PL__ctx);
   if ( m != mp )
     releaseModule(m);
 
@@ -650,10 +651,10 @@ PRED_IMPL("$local_op", 3, local_op, PL_FA_NONDETERMINISTIC|PL_FA_TRANSPARENT)
   if ( CTX_CNTRL != FRG_CUTTED )
   { if ( !(name = PL_new_term_ref()) ||
 	 !get_op_module(A3, name, &m) )
-      return FALSE;
+      return false;
   }
 
-  return current_op(m, FALSE, A1, A2, name, PL__ctx);
+  return current_op(m, false, A1, A2, name, PL__ctx);
 }
 
 
@@ -682,6 +683,7 @@ static const opdef operators[] = {
   OP(ATOM_prove,		 OP_FX,	 1200),	/* :- */
   OP(ATOM_prove,		 OP_XFX, 1200),
   OP(ATOM_ssu_commit,		 OP_XFX, 1200), /* => */
+  OP(ATOM_ssu_dcg,		 OP_XFX, 1200), /* ==> */
 //OP(ATOM_ssu_choice,		 OP_XFX, 1200), /* ?=> */
   OP(ATOM_semicolon,		 OP_XFY, 1100),	/* ; */
   OP(ATOM_bar,			 OP_XFY, 1105),	/* | */
@@ -740,11 +742,11 @@ initOperators(void)
   MODULE_system->operators = newOperatorTable(128);
 
   for( op = operators; op->name; op++ )
-    defOperator(MODULE_system, op->name, op->type, op->priority, TRUE);
+    defOperator(MODULE_system, op->name, op->type, op->priority, true);
 
   if ( !GD->options.traditional )
-  { defOperator(MODULE_system, PL_new_atom("."), OP_YFX, 100, TRUE);
-    defOperator(MODULE_system, ATOM_colon_eq,    OP_XFX, 800, TRUE);
+  { defOperator(MODULE_system, PL_new_atom("."), OP_YFX, 100, true);
+    defOperator(MODULE_system, ATOM_colon_eq,    OP_XFX, 800, true);
   }
 }
 
