@@ -95,7 +95,7 @@ static void initSignals(void);
 static void gcPolicy(Stack s, int policy);
 #undef LDFUNC_DECLARATIONS
 
-int
+bool
 setupProlog(void)
 { GET_LD
   DEBUG(1, Sdprintf("Starting Heap Initialisation\n"));
@@ -150,7 +150,9 @@ setupProlog(void)
   DEBUG(1, Sdprintf("Flags ...\n"));
   initFlags();
   DEBUG(1, Sdprintf("Foreign Predicates ...\n"));
-  initBuildIns();
+  initBuildIns(false);
+  DEBUG(1, Sdprintf("VM ...\n"));
+  initVM();
   DEBUG(1, Sdprintf("Malloc binding ...\n"));
   initMalloc();
   DEBUG(1, Sdprintf("Operators ...\n"));
@@ -330,6 +332,18 @@ static struct signame
 #ifdef SIGPWR
   { SIGPWR,	"pwr",    0},
 #endif
+#ifdef SIGEMT
+  { SIGEMT,	"emt",    0},
+#endif
+#ifdef SIGSYS
+  { SIGSYS,	"sys",    0},
+#endif
+#ifdef SIGWINCH
+  { SIGWINCH,	"winch",  0},
+#endif
+#ifdef SIGINFO
+  { SIGINFO,	"info",   0},
+#endif
 #endif /*HAVE_OS_SIGNALS*/
 
 /* The signals below here are recorded as Prolog interrupts, but
@@ -345,6 +359,7 @@ static struct signame
 #endif
   { SIG_CLAUSE_GC,     "prolog:clause_gc",     0 },
   { SIG_PLABORT,       "prolog:abort",         0 },
+  { SIG_PLHALT,        "prolog:halt",          0 },
 
   { -1,		NULL,     0}
 };
@@ -557,7 +572,7 @@ dispatch_signal(int sig, int sync)
 #endif
   } else if ( ison(sh, PLSIG_THROW) )
   { char *predname;
-    int  arity;
+    size_t arity;
 
     if ( environment_frame )
     { predname = stringAtom(environment_frame->predicate->functor->name);
@@ -603,7 +618,10 @@ dispatch_signal(int sig, int sync)
 					/* longjmp.  If that fails, crash */
   if ( is_fatal_signal(sig) )
   { if ( exception_term )
-    { PL_rethrow();
+    {
+#if O_THROW
+      PL_rethrow();
+#endif
       sigCrashHandler(sig);
     }
     exit(4);
@@ -779,7 +797,7 @@ alt_segv_handler(int sig)
 }
 #endif
 
-int
+bool
 initGuardCStack(void)
 {
 #ifdef O_C_STACK_GUARDED
@@ -853,6 +871,18 @@ abort_handler(int sig)
   abortProlog();
 }
 
+static void
+halt_handler(int sig)
+{ GET_LD
+  (void)sig;
+
+  if ( !raise_halt_exception(GD->halt.status, true) )
+  { Sdprintf("Failed to raise unwind(halt(%d))\n",
+	     GD->halt.status&PL_CLEANUP_STATUS_MASK);
+    abortProlog();
+  }
+}
+
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 The idea behind alert_handler() is to  make blocking system calls return
@@ -918,6 +948,7 @@ initSignals(DECL_LD)
   PL_signal(SIG_TUNE_GC|PL_SIGSYNC,	  gc_tune_handler);
   PL_signal(SIG_CLAUSE_GC|PL_SIGSYNC,     cgc_handler);
   PL_signal(SIG_PLABORT|PL_SIGSYNC,       abort_handler);
+  PL_signal(SIG_PLHALT|PL_SIGSYNC,        halt_handler);
 #ifdef SIG_THREAD_SIGNAL
   PL_signal(SIG_THREAD_SIGNAL|PL_SIGSYNC, executeThreadSignals);
 #endif
@@ -1282,7 +1313,7 @@ startCritical(DECL_LD)
 }
 
 
-int
+bool
 endCritical(DECL_LD)
 { if ( --LD->critical == 0 && LD->alerted && exception_term )
     return false;
@@ -1450,7 +1481,7 @@ both at system startup to create the stack   for the main thread as from
 pl-thread.c to create stacks for Prolog threads.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-int
+bool
 initPrologStacks(size_t limit)
 { GET_LD
 
@@ -1624,7 +1655,7 @@ freeStacks(DECL_LD)
 }
 
 
-int
+void
 trim_stack(Stack s)
 { if ( s->spare < s->def_spare )
   { ssize_t reduce = s->def_spare - s->spare;
@@ -1641,8 +1672,6 @@ trim_stack(Stack s)
     s->max = addPointer(s->max, -reduce);
     s->spare += reduce;
   }
-
-  return false;
 }
 
 
@@ -1821,7 +1850,7 @@ no_local_ld(void)
 		 *	     PREDICATES		*
 		 *******************************/
 
-int
+bool
 set_stack_limit(size_t limit)
 { GET_LD
 
